.. _examples:

Examples of aiothrift usage
===========================

sample thrift file
^^^^^^^^^^^^^^^^^^

:download:`get source code<../examples/pingpong.thrift>`

.. literalinclude:: ../examples/pingpong.thrift

aio thrift server
^^^^^^^^^^^^^^^^^

:download:`get source code<../examples/server.py>`

.. literalinclude:: ../examples/server.py


aio thrift client
^^^^^^^^^^^^^^^^^

:download:`get source code<../examples/client.py>`

.. literalinclude:: ../examples/client.py


connection pool sample
^^^^^^^^^^^^^^^^^^^^^^

:download:`get source code<../examples/pool.py>`

.. literalinclude:: ../examples/pool.py

